@@ -1119,7 +1119,7 @@ class Chemical:
         self._init_energies(self._Cn, self._Hvap, self._Psat, self._Hfus,
                             self._Tm, self._Tb, self._eos, self._eos_1atm,
                             phase_ref)
-        if self._Hf: self.reset_combustion_data()
+        if self._formula and self._Hf is not None: self.reset_combustion_data()
 
     def reset_combustion_data(self, method="Stoichiometry"):
         """Reset combustion data (LHV, HHV, and combution attributes)
@@ -1188,10 +1188,10 @@ class Chemical:
         self._Tt = Tt or triple_point_temperature(CAS)
 
         # Energy
-        self._Hfus = Hfus or heat_of_fusion(CAS)
+        self._Hfus = Hfus if Hf is not None else heat_of_fusion(CAS)
 
         # Chemistry
-        self._Hf = Hf or heat_of_formation(CAS)
+        self._Hf = Hf if Hf is not None else heat_of_formation(CAS)
         atoms = self.atoms
         if not all([LHV, HHV, combustion]) and atoms and Hf:
             CD = CombustionData.from_chemical_data(
