@@ -592,6 +592,11 @@ class Stream:
         """[float] Entropy flow rate in kJ/hr."""
         return self.mixture.S(self.phase, self.mol, *self._thermal_condition)
     
+    @property
+    def Hnet(self):
+        """[float] Total enthalpy flow rate (including heats of formation) in kJ/hr."""
+        return self.H + self.Hf
+    
     @property
     def Hf(self):
         """[float] Enthalpy of formation flow rate in kJ/hr."""
