@@ -44,6 +44,22 @@ class ThermalCondition:
         """tuple[float, float] Temperature and pressure"""
         return (self.T, self.P)
     
+    def __getitem__(self, index):
+        if index == 0:
+            return self.T
+        elif index == 1:
+            return self.P
+        else:
+            raise IndexError('index out of range')
+    
+    def __setitem__(self, index, value):
+        if index == 0:
+            self.T = value
+        elif index == 1:
+            self.P = value
+        else:
+            raise IndexError('index out of range')
+    
     def __iter__(self):
         yield self.T
         yield self.P
