@@ -7,7 +7,7 @@ Created on Sat Nov 30 20:18:27 2019
 from . import equilibrium as eq
 from ._chemical import Chemical
 from ._chemicals import Chemicals
-from .mixture import Mixture, new_ideal_mixture
+from .mixture import Mixture, ideal_mixture
 from .utils import read_only, cucumber
 from ._settings import settings
 
@@ -37,7 +37,7 @@ class Thermo:
     --------
     >>> from thermosteam import Thermo
     >>> Thermo(['Ethanol', 'Water'])
-    Thermo(chemicals=CompiledChemicals([Ethanol, Water]), mixture=IdealMixture(...), Gamma=DortmundActivityCoefficients, Phi=IdealFugacityCoefficients, PCF=IdealPoyintingCorrectionFactors)
+    Thermo(chemicals=CompiledChemicals([Ethanol, Water]), mixture=Mixture(rule='ideal mixing', ..., rigorous_energy_balance=True, include_excess_energies=False), Gamma=DortmundActivityCoefficients, Phi=IdealFugacityCoefficients, PCF=IdealPoyintingCorrectionFactors)
     
     Attributes
     ----------
@@ -64,7 +64,7 @@ class Thermo:
             assert isinstance(mixture, Mixture), (
                 f"mixture must be a '{Mixture.__name__}' object")
         else:
-            mixture = new_ideal_mixture(chemicals)
+            mixture = ideal_mixture(chemicals)
         chemicals.compile()
         if settings._debug:
             issubtype = issubclass
@@ -109,5 +109,6 @@ class Thermo:
               f"    mixture={mixture_info},\n"
               f"    Gamma={self.Gamma.__name__},\n"
               f"    Phi={self.Phi.__name__},\n"
-              f"    PCF={self.PCF.__name__})")
+              f"    PCF={self.PCF.__name__}\n"
+               ")")
     _ipython_display_ = show
\ No newline at end of file
