@@ -91,9 +91,6 @@ class ThermoModelHandle:
         """Deque[ThermoModel] All models."""
         return self._models
     
-    def load_data_from(self, data:dict):
-        for model in self._models: model.load_data_from(data)
-    
     def set_value(self, var, value):
         for model in self._models: model.set_value(var, value)
     
