@@ -15,6 +15,7 @@ from . import bubble_point
 from . import poyinting_correction_factors
 from . import fugacities
 from . import lle
+from . import plot_equilibrium
 
 __all__ = (*activity_coefficients.__all__,
            *vle.__all__,
@@ -23,7 +24,8 @@ __all__ = (*activity_coefficients.__all__,
            *bubble_point.__all__,
            *fugacity_coefficients.__all__,
            *poyinting_correction_factors.__all__,
-           *fugacities.__all__,)
+           *fugacities.__all__,
+           *plot_equilibrium.__all__)
 
 from .vle import *
 from .lle import *
@@ -33,5 +35,6 @@ from .poyinting_correction_factors import *
 from .dew_point import *
 from .bubble_point import *
 from .fugacities import *
+from .plot_equilibrium import *
 
 
