@@ -8,10 +8,10 @@ from numpy import asarray, array
 from flexsolve import aitken_secant, IQ_interpolation
 from .solve_vle_composition import solve_y
 from ..functional import normalize
-from ..utils import fill_like
+from ..utils import fill_like, Cache
 from .._settings import settings
 
-__all__ = ('BubblePoint', 'BubblePointValues')
+__all__ = ('BubblePoint', 'BubblePointValues', 'BubblePointCache')
 
 # %% Bubble point values container
 
@@ -44,18 +44,17 @@ class BubblePoint:
     Examples
     --------
     >>> import thermosteam as tmo
-    >>> import numpy as np
     >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
     >>> tmo.settings.set_thermo(chemicals)
     >>> BP = tmo.equilibrium.BubblePoint(chemicals)
-    >>> molar_composition = np.array([0.5, 0.5])
+    >>> molar_composition = (0.5, 0.5)
     >>> # Solve bubble point at constant temperature
     >>> bp = BP(z=molar_composition, T=355)
     >>> bp
-    BubblePointValues(T=355, P=109755.45319869413, IDs=('Water', 'Ethanol'), z=[0.5 0.5], y=[0.343 0.657])
+    BubblePointValues(T=355, P=109755.45319869411, IDs=('Water', 'Ethanol'), z=[0.5 0.5], y=[0.343 0.657])
     >>> # Note that the result is a BubblePointValues object which contain all results as attibutes
     >>> (bp.T, bp.P, bp.IDs, bp.z, bp.y)
-    (355, 109755.45319869413, ('Water', 'Ethanol'), array([0.5, 0.5]), array([0.343, 0.657]))
+    (355, 109755.45319869411, ('Water', 'Ethanol'), array([0.5, 0.5]), array([0.343, 0.657]))
     >>> # Solve bubble point at constant pressure
     >>> BP(z=molar_composition, P=101325)
     BubblePointValues(T=352.95030269946596, P=101325, IDs=('Water', 'Ethanol'), z=[0.5 0.5], y=[0.342 0.658])
@@ -98,6 +97,7 @@ class BubblePoint:
         return 1. - self.y.sum()
     
     def __call__(self, z, *, T=None, P=None):
+        z = asarray(z, float)
         if T:
             if P: raise ValueError("may specify either T or P, not both")
             P, y = self.solve_Py(z, T)
@@ -113,7 +113,7 @@ class BubblePoint:
 
         Parameters
         ----------
-        z : array_like
+        z : ndarray
             Molar composotion.
         P : float
             Pressure [Pa].
@@ -122,21 +122,20 @@ class BubblePoint:
         -------
         T : float 
             Bubble point temperature [K].
-        y : numpy.ndarray
+        y : ndarray
             Vapor phase molar composition.
 
         Examples
         --------
         >>> import thermosteam as tmo
+        >>> import numpy as np
         >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
         >>> tmo.settings.set_thermo(chemicals)
         >>> BP = tmo.equilibrium.BubblePoint(chemicals)
-        >>> BP.solve_Ty(z=(0.6, 0.4), P=101325)
+        >>> BP.solve_Ty(z=np.array([0.6, 0.4]), P=101325)
         (353.7543445955407, array([0.381, 0.619]))
         
         """
-        
-        z = asarray(z)
         z_norm = z / z.sum()
         self.P = P
         args = (P, z_norm/P, z_norm)
@@ -163,7 +162,7 @@ class BubblePoint:
 
         Parameters
         ----------
-        z : array_like
+        z : ndarray
             Molar composotion.
         T : float
             Temperature [K].
@@ -172,20 +171,20 @@ class BubblePoint:
         -------
         P : float
             Bubble point pressure [Pa].
-        y : numpy.ndarray
+        y : ndarray
             Vapor phase molar composition.
 
         Examples
         --------
         >>> import thermosteam as tmo
+        >>> import numpy as np
         >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
         >>> tmo.settings.set_thermo(chemicals)
         >>> BP = tmo.equilibrium.BubblePoint(chemicals)
-        >>> BP.solve_Py(z=(0.703, 0.297), T=352.28)
-        (91830.9798895787, array([0.419, 0.581]))
+        >>> BP.solve_Py(z=np.array([0.703, 0.297]), T=352.28)
+        (91830.97988957874, array([0.419, 0.581]))
         
         """
-        z = asarray(z)
         Psat = array([i(T) for i in self.Psats])
         z_norm = z / z.sum()
         y_phi = z * Psat * self.gamma(z_norm, T) * self.pcf(z_norm, T)
@@ -206,5 +205,6 @@ class BubblePoint:
         chemicals = ", ".join([i.ID for i in self.chemicals])
         return f"{type(self).__name__}([{chemicals}])"
     
-
+class BubblePointCache(Cache): load = BubblePoint
+del Cache
     
\ No newline at end of file
