@@ -12,8 +12,15 @@ __all__ = ('solve_x', 'solve_y')
 def x_iter(x, x_gamma_poyinting, gamma, poyinting, T):
     x = normalize(x)
     # Add back trace amounts for activity coefficients at infinite dilution
-    x[x < 1e-16] = 1e-16
-    return x_gamma_poyinting / (gamma(x, T) * poyinting(x, T))
+    mask = x < 1e-16
+    x[mask] = 1e-16
+    denominator = gamma(x, T) * poyinting(x, T)
+    try:
+        x = x_gamma_poyinting / denominator
+    except FloatingPointError: 
+        x[mask] = 0
+        x = normalize(x)
+    return x
 
 def solve_x(x_gamma_poyinting, gamma, poyinting, T, x_guess=None):
     if x_guess is None: x_guess = x_gamma_poyinting
