@@ -4,18 +4,18 @@ Created on Wed Mar 20 18:40:05 2019
 
 @author: yoelr
 """
-from flexsolve import wegstein, IQ_interpolation, fixed_point, SolverError
+from flexsolve import wegstein, IQ_interpolation, aitken, SolverError
 from ..utils.decorator_utils import thermo_user
 from .binary_phase_fraction import phase_fraction
-from .dew_point import DewPoint
-from .bubble_point import BubblePoint
+from .dew_point import DewPointCache
+from .bubble_point import BubblePointCache
 from .fugacity_coefficients import IdealFugacityCoefficients
 from .._thermal_condition import ThermalCondition
 from ..functional import normalize
 from ..utils import Cache
 import numpy as np
 
-__all__ = ('VLE',)
+__all__ = ('VLE', 'VLECache')
 
 @thermo_user
 class VLE:
@@ -97,8 +97,8 @@ class VLE:
     def __init__(self, imol, thermal_condition=None,
                  thermo=None, bubble_point_cache=None, dew_point_cache=None):
         self._T = self._P = self._H_hat = self._V = 0
-        self._dew_point_cache = dew_point_cache or Cache(DewPoint)
-        self._bubble_point_cache = bubble_point_cache or Cache(BubblePoint)
+        self._dew_point_cache = dew_point_cache or DewPointCache()
+        self._bubble_point_cache = bubble_point_cache or BubblePointCache()
         self._load_thermo(thermo)
         self._imol = imol
         self._thermal_condition = thermal_condition or ThermalCondition(298.15, 101325.)
@@ -205,8 +205,8 @@ class VLE:
             else:
                 # Set equilibrium objects
                 thermo = self._thermo
-                self._bubble_point = bp = self._bubble_point_cache.reload(eq_chems, thermo)
-                self._dew_point = self._dew_point_cache.reload(eq_chems, thermo)
+                self._bubble_point = bp = self._bubble_point_cache(eq_chems, thermo)
+                self._dew_point = self._dew_point_cache(eq_chems, thermo)
                 self._pcf = bp.pcf
                 self._gamma = bp.gamma
                 self._phi = bp.phi
@@ -647,7 +647,7 @@ class VLE:
                                 self._x, 1e-12,
                                 args=(Psat_over_P_phi,))
         except SolverError as solver_error:
-            x = fixed_point(self._x_iter,
+            x = aitken(self._x_iter,
                             solver_error.x, 1e-6,
                             args=(Psat_over_P_phi,))
         self._x = x
@@ -685,3 +685,6 @@ class VLE:
     
     def __repr__(self):
         return self.__format__("1")
+
+class VLECache(Cache): load = VLE
+del Cache    
\ No newline at end of file
