@@ -51,7 +51,7 @@ class Mixture:
     See also
     --------
     IdealMixtureModel
-    ideal_mixture
+    :func:`~.mixture_builders.ideal_mixture`
     
     Attributes
     ----------
